@@ -1,4 +1,6 @@
+import math
 from enum import IntEnum, auto
+from typing import Optional
 
 from ..constants import EveGroupId
 from ..models.eveuniverse import EveType
@@ -29,9 +31,10 @@ def starbase_size(eve_type: EveType) -> StarbaseSize:
     return StarbaseSize.LARGE
 
 
-def starbase_fuel_per_hour(eve_type: EveType):
-    """returns the number of fuel blocks consumed per hour
-    or None if not a starbase
+def fuel_per_hour(eve_type: EveType) -> Optional[int]:
+    """Calculate the number of fuel blocks consumed per hour.
+
+    Returns None if not a starbase.
     """
     size = starbase_size(eve_type)
     if size is StarbaseSize.LARGE:
@@ -41,3 +44,19 @@ def starbase_fuel_per_hour(eve_type: EveType):
     elif size is StarbaseSize.SMALL:
         return 10
     return None
+
+
+def fuel_duration(
+    starbase_type: EveType,
+    fuel_quantity: int,
+    has_sov: bool = False,
+) -> float:
+    """Calculate how long the fuel lasts in seconds."""
+    sov_discount = 0.25 if has_sov else 0
+    amount_per_hour = fuel_per_hour(starbase_type)
+    if amount_per_hour is None:
+        raise ValueError(
+            f"{starbase_type}: Can only calculate fuel durations for starbases"
+        )
+    seconds = math.floor(3600 * fuel_quantity / (amount_per_hour * (1 - sov_discount)))
+    return seconds
